% Test av statisk divergens, Henrik Skyvulstad

%Bruksanvisning:

%Statisk divergens PS: bruker quasistatiske koeffisienter
clc
clear all
close all

%% 
%Velger her den laveste i torsjon
VALGT=[19];                              %Laveste i torsjon, ps. kan kun velge 1!!!
Nodes=186;                               %Antall noder i abaqusmodellen

%konstanter til uthenting av mode
rho=1.25;                                %tetthet luft
L=3700;                                  %Lengde brua i meter
B=18.3;                                  %bredde p brua i henhold til de aerodyn
d=3.3;                                   %dybde p brua

%% Importer abaqus data
[Eigenvectors,Eigenvalues]=read_ABAQUS_dat('H.dat',Nodes);    %sett inn navn p DAT fila som skal sjekkes
omegaomega=(Eigenvalues(VALGT,3));

%% Definerer moden.
Koordinater=Eigenvectors(:,2:4);
[~, b]=sort(Koordinater(:,1));
Koordinater=Koordinater(b,:);clc

phiphi=zeros(3,size(Eigenvectors,1),length(VALGT));
teller=1;
for n=1:length(omegaomega)
    phiphi(2,:,teller)=Eigenvectors(b,6,VALGT(n))';
    phiphi(1,:,teller)=Eigenvectors(b,7,VALGT(n))';
    phiphi(3,:,teller)=Eigenvectors(b,8,VALGT(n))';
    Skalering=max([phiphi(1,:,teller) phiphi(2,:,teller) B/2*phiphi(3,:,teller) ]);
    figure
%     subplot(3,1,1)
%     plot(Koordinater(:,1),phiphi(1,:,teller))
%     ylim([-Skalering Skalering])
%     title(['Mode ' num2str(VALGT(n)) ' \omega=' num2str(omegaomega(teller,1)) ' (rad/s)'])
%     grid on
%     subplot(3,1,2)
%     plot(Koordinater(:,1),phiphi(2,:,teller))
%     ylim([-Skalering Skalering])
%     grid on
%     subplot(3,1,3)
%     plot(Koordinater(:,1),phiphi(3,:,teller))
%     ylim([-2/B*Skalering 2/B*Skalering])
%     grid on
%     teller=teller+1;
end
%% Definer stille luft egenskapene
omegaomega=diag(Eigenvalues(VALGT,3));
M=diag(Eigenvalues(VALGT,5));
zetazeta=0.005.*diag(ones(length(VALGT),1));
K=omegaomega.^2*M;
C=2.*zetazeta.*M.*omegaomega;
omega=diag(omegaomega);

%Konstanter

V=20:10:500;                %Vindomrdet

omegat=omegaomega(1,1);     %husk at alltid torsjon m ha strt frekvens!!!            
ksit=0.005;                 %Modal demping
dx=L/(Nodes-1);             %itterasjonslengde
Lexp=3700;                  %eksponert lengde i meter
dxexp=L/(Nodes-1);          %eksponert itterasjonslende 
x=0:dx:L;                   %Lengdevektor hele brua
xexp=0:dxexp:Lexp;          %Lengdevektor eksponert
phi1=phiphi(1,:,1);         %formfuntion vertikal
phi2=phiphi(2,:,1);         %formfuntion horisontal
phi3=phiphi(3,:,1);         %formfuntion for torsjon
mt=M(1,1)/(sum(phi2.^2)*dx);%Modal massematrise (ps. antatt kun torsjonssvinninger)

for a=1:1:length(x)
dx1(1,a)=dx;
dxexp1(1,a)=dxexp;
end

phi=[phi1;phi2;phi3];       %formfuntionsmatrise

%Drag, lift of moment koeffisienter(Hardangerbrua)

%middel
CDs=0.749;                            %disse med strek over, middel verdien! 
CLs=-0.254;
CMs=0.004;

%helning
CDm=0;    %angir ikke CDm              %m angir merket, alts helningen
CLm=2.502;
CMm=0.859;

%Aeroelastisk stivhets matrise, ps. kvasistatisk teori

for e=1:1:length(V)
    
Kae(:,:,e)=(rho*B^2)*(1/2)*[0,0,CDm*(d/B)*(V(e)/B).^2;0,0,CLm*B*(V(e)/B).^2;0,0,CMm*B^2*(V(e)/B).^2];

end

%Modal stivhet
K=M(1,1)*omegaomega(1,1)^2; %modalstivhetsmatrise

kae=zeros(1,1,length(V));   

for w=1:1:length(V)         %generering av modal aeroelsatisk stivhet
    for u=1:1:length(x)
        kae(1,1,w)=kae(1,1,w)+phi(:,u)'*Kae(:,:,w)*phi(:,u)*dx;
    end
end

digits(64);                             %ker nyaktigheten
Eq1(1,:)=K-kae(1,1,:);                  %ligning fra impedance matrisa
k=find(abs(Eq1(1,:))~=Eq1(1,:));        %finner ledd i rekka hvor Eq1 skrifter fortegn
Vcr=V(k(1,1))                           %finner kritisk vindhastighet
digits(32);                             %senker nyaktigheten til difouldt igjenn


plot(V,Eq1(1,:))
grid on





